diff --git a/indra/newview/viewer_manifest.py b/indra/newview/viewer_manifest.py
index 1e58cec808a3278b3210e749cb32965f240d88bd..3e8bb388d2ca09756df419c6623e9538e520855d 100755
--- a/indra/newview/viewer_manifest.py
+++ b/indra/newview/viewer_manifest.py
@@ -497,9 +497,7 @@ def construct(self):
 
             with self.prefix(src=os.path.join(pkgdir, "VMP")):
                 # include the compiled launcher scripts so that it gets included in the file_list
-                self.path('updater.exe')
-                #IUM is not normally executed directly, just imported.  No exe needed.
-                self.path("InstallerUserMessage.py")
+                self.path('SLVersionChecker.exe')
 
             with self.prefix(dst="vmp_icons"):
                 with self.prefix(src=self.icon_path()):
@@ -713,7 +711,7 @@ def construct(self):
                 self.path("libvlccore.dll")
                 self.path("plugins/")
 
-        # pull in the crash logger and updater from other projects
+        # pull in the crash logger from other projects
         # tag:"crash-logger" here as a cue to the exporter
         self.path(src='../win_crash_logger/%s/windows-crash-logger.exe' % self.args['configuration'],
                   dst="win_crash_logger.exe")
@@ -783,7 +781,7 @@ def package_finish(self):
         substitution_strings['installer_file'] = installer_file
         
         version_vars = """
-        !define INSTEXE "updater.exe"
+        !define INSTEXE "SLVersionChecker.exe"
         !define VERSION "%(version_short)s"
         !define VERSION_LONG "%(version)s"
         !define VERSION_DASHES "%(version_dashes)s"
@@ -828,7 +826,7 @@ def package_finish(self):
         # Unlike the viewer binary, the VMP filenames are invariant with respect to version, os, etc.
         for exe in (
             self.final_exe(),
-            "updater.exe",
+            "SLVersionChecker.exe",
             ):
             self.sign(exe)
diff --git a/indra/newview/llappviewer.cpp b/indra/newview/llappviewer.cpp
index bda76c14d1c5b3bfe3e2d9513782ef537970c555..d3577d50a1ab3327219452b4c56587582a26e091 100644
--- a/indra/newview/llappviewer.cpp
+++ b/indra/newview/llappviewer.cpp
@@ -1140,13 +1140,13 @@ bool LLAppViewer::init()
 	// viewer itself.
 	updater.autokill = false;
 #if LL_WINDOWS
-	updater.executable = gDirUtilp->getExpandedFilename(LL_PATH_EXECUTABLE, "updater.exe");
+	updater.executable = gDirUtilp->getExpandedFilename(LL_PATH_EXECUTABLE, "SLVersionChecker.exe");
 #elif LL_DARWIN
 	// explicitly run the system Python interpreter on updater.py
 	updater.executable = "python";
-	updater.args.add(gDirUtilp->add(gDirUtilp->getAppRODataDir(), "updater", "updater.py"));
+	updater.args.add(gDirUtilp->add(gDirUtilp->getAppRODataDir(), "updater", "SLVersionChecker.py"));
 #else
-	updater.executable = gDirUtilp->getExpandedFilename(LL_PATH_EXECUTABLE, "updater");
+	updater.executable = gDirUtilp->getExpandedFilename(LL_PATH_EXECUTABLE, "SLVersionChecker");
 #endif
 	// add LEAP mode command-line argument to whichever of these we selected
 	updater.args.add("leap");
@@ -1140,13 +1140,13 @@ bool LLAppViewer::init()
 #elif LL_DARWIN
-	// explicitly run the system Python interpreter on updater.py
+	// explicitly run the system Python interpreter on SLVersionChecker.py
 	updater.executable = "python";